@@ -14,39 +14,20 @@
 
 import contextlib
 import fnmatch
-import functools
 import inspect
+import ipaddress
 import re
-import time
+import socket
 import uuid
+import warnings
 
 from decorator import decorator
 import jmespath
-import netifaces
+import psutil
 
 from openstack import _log
-from openstack.cloud import exc
-
-
-_decorated_methods = []
-
-
-def _make_unicode(input):
-    """Turn an input into unicode unconditionally
-
-    :param input: A unicode, string or other object
-    """
-    try:
-        if isinstance(input, unicode):
-            return input
-        if isinstance(input, str):
-            return input.decode('utf-8')
-        else:
-            # int, for example
-            return unicode(input)
-    except NameError:
-        # python3!
-        return str(input)
+from openstack import exceptions
+from openstack import warnings as os_warnings
 
 
 def _dictify_resource(resource):
@@ -70,12 +51,7 @@ def _filter_list(data, name_or_id, filters):
     :param filters: A dictionary of meta data to use for further filtering.
         Elements of this dictionary may, themselves, be dictionaries. Example::
 
-            {
-                'last_name': 'Smith',
-                'other': {
-                    'gender': 'Female'
-                }
-            }
+            {'last_name': 'Smith', 'other': {'gender': 'Female'}}
 
         OR
 
@@ -88,7 +64,7 @@ def _filter_list(data, name_or_id, filters):
     log = _log.setup_logging('openstack.fnmatch')
     if name_or_id:
         # name_or_id might already be unicode
-        name_or_id = _make_unicode(name_or_id)
+        name_or_id = str(name_or_id)
         identifier_matches = []
         bad_pattern = False
         try:
@@ -100,8 +76,8 @@ def _filter_list(data, name_or_id, filters):
             # search
             fn_reg = None
         for e in data:
-            e_id = _make_unicode(e.get('id', None))
-            e_name = _make_unicode(e.get('name', None))
+            e_id = str(e.get('id', None))
+            e_name = str(e.get('name', None))
 
             if (e_id and e_id == name_or_id) or (
                 e_name and e_name == name_or_id
@@ -126,6 +102,12 @@ def _filter_list(data, name_or_id, filters):
         return data
 
     if isinstance(filters, str):
+        warnings.warn(
+            'Support for jmespath-style filters is deprecated and will be '
+            'removed in a future release. Consider using dictionary-style '
+            'filters instead.',
+            os_warnings.RemovedInSDK60Warning,
+        )
         return jmespath.search(filters, data)
 
     def _dict_filter(f, d):
@@ -187,21 +169,21 @@ def _get_entity(cloud, resource, name_or_id, filters, **kwargs):
     # If a uuid is passed short-circuit it calling the
     # get_<resource_name>_by_id method
     if getattr(cloud, 'use_direct_get', False) and _is_uuid_like(name_or_id):
-        get_resource = getattr(cloud, 'get_%s_by_id' % resource, None)
+        get_resource = getattr(cloud, f'get_{resource}_by_id', None)
         if get_resource:
             return get_resource(name_or_id)
 
     search = (
         resource
         if callable(resource)
-        else getattr(cloud, 'search_%ss' % resource, None)
+        else getattr(cloud, f'search_{resource}s', None)
     )
     if search:
         entities = search(name_or_id, filters, **kwargs)
         if entities:
             if len(entities) > 1:
-                raise exc.OpenStackCloudException(
-                    "Multiple matches found for %s" % name_or_id
+                raise exceptions.SDKException(
+                    f"Multiple matches found for {name_or_id}"
                 )
             return entities[0]
     return None
@@ -210,15 +192,19 @@ def _get_entity(cloud, resource, name_or_id, filters, **kwargs):
 def localhost_supports_ipv6():
     """Determine whether the local host supports IPv6
 
-    We look for a default route that supports the IPv6 address family,
-    and assume that if it is present, this host has globally routable
-    IPv6 connectivity.
+    We look for the all ip addresses configured to this node, and assume that
+    if any of these is IPv6 address (but not loopback or link local), this host
+    has IPv6 connectivity.
     """
 
-    try:
-        return netifaces.AF_INET6 in netifaces.gateways()['default']
-    except AttributeError:
-        return False
+    for ifname, if_addrs in psutil.net_if_addrs().items():
+        for if_addr in if_addrs:
+            if if_addr.family != socket.AF_INET6:
+                continue
+            addr = ipaddress.ip_address(if_addr.address)
+            if not addr.is_link_local and not addr.is_loopback:
+                return True
+    return False
 
 
 def valid_kwargs(*valid_args):
@@ -241,76 +227,37 @@ def valid_kwargs(*valid_args):
         for k in kwargs:
             if k not in argspec.args[1:] and k not in valid_args:
                 raise TypeError(
-                    "{f}() got an unexpected keyword argument "
-                    "'{arg}'".format(f=inspect.stack()[1][3], arg=k)
+                    f"{inspect.stack()[1][3]}() got an unexpected keyword "
+                    f"argument '{k}'"
                 )
         return func(*args, **kwargs)
 
     return func_wrapper
 
 
-def _func_wrap(f):
-    # NOTE(morgan): This extra wrapper is intended to eliminate ever
-    # passing a bound method to dogpile.cache's cache_on_arguments. In
-    # 0.7.0 and later it is impossible to pass bound methods to the
-    # decorator. This was introduced when utilizing the decorate module in
-    # lieu of a direct wrap implementation.
-    @functools.wraps(f)
-    def inner(*args, **kwargs):
-        return f(*args, **kwargs)
-
-    return inner
-
-
-def cache_on_arguments(*cache_on_args, **cache_on_kwargs):
-    _cache_name = cache_on_kwargs.pop('resource', None)
-
-    def _inner_cache_on_arguments(func):
-        def _cache_decorator(obj, *args, **kwargs):
-            the_method = obj._get_cache(_cache_name).cache_on_arguments(
-                *cache_on_args, **cache_on_kwargs
-            )(_func_wrap(func.__get__(obj, type(obj))))
-            return the_method(*args, **kwargs)
-
-        def invalidate(obj, *args, **kwargs):
-            return (
-                obj._get_cache(_cache_name)
-                .cache_on_arguments()(func)
-                .invalidate(*args, **kwargs)
-            )
-
-        _cache_decorator.invalidate = invalidate
-        _cache_decorator.func = func
-        _decorated_methods.append(func.__name__)
-
-        return _cache_decorator
-
-    return _inner_cache_on_arguments
-
-
 @contextlib.contextmanager
 def openstacksdk_exceptions(error_message=None):
     """Context manager for dealing with openstack exceptions.
 
     :param string error_message: String to use for the exception message
-        content on non-OpenStackCloudExceptions.
+        content on non-SDKException exception.
 
-        Useful for avoiding wrapping OpenStackCloudException exceptions
+        Useful for avoiding wrapping SDKException exceptions
         within themselves. Code called from within the context may throw such
         exceptions without having to catch and reraise them.
 
-        Non-OpenStackCloudException exceptions thrown within the context will
+        Non-SDKException exceptions thrown within the context will
         be wrapped and the exception message will be appended to the given
         error message.
     """
     try:
         yield
-    except exc.OpenStackCloudException:
+    except exceptions.SDKException:
         raise
     except Exception as e:
         if error_message is None:
             error_message = str(e)
-        raise exc.OpenStackCloudException(error_message)
+        raise exceptions.SDKException(error_message)
 
 
 def safe_dict_min(key, data):
@@ -335,11 +282,9 @@ def safe_dict_min(key, data):
             try:
                 val = int(d[key])
             except ValueError:
-                raise exc.OpenStackCloudException(
+                raise exceptions.SDKException(
                     "Search for minimum value failed. "
-                    "Value for {key} is not an integer: {value}".format(
-                        key=key, value=d[key]
-                    )
+                    f"Value for {key} is not an integer: {d[key]}"
                 )
             if (min_value is None) or (val < min_value):
                 min_value = val
@@ -368,69 +313,15 @@ def safe_dict_max(key, data):
             try:
                 val = int(d[key])
             except ValueError:
-                raise exc.OpenStackCloudException(
+                raise exceptions.SDKException(
                     "Search for maximum value failed. "
-                    "Value for {key} is not an integer: {value}".format(
-                        key=key, value=d[key]
-                    )
+                    f"Value for {key} is not an integer: {d[key]}"
                 )
             if (max_value is None) or (val > max_value):
                 max_value = val
     return max_value
 
 
-def _call_client_and_retry(
-    client, url, retry_on=None, call_retries=3, retry_wait=2, **kwargs
-):
-    """Method to provide retry operations.
-
-    Some APIs utilize HTTP errors on certain operations to indicate that
-    the resource is presently locked, and as such this mechanism provides
-    the ability to retry upon known error codes.
-
-    :param object client: The client method, such as:
-        ``self.baremetal_client.post``
-    :param string url: The URL to perform the operation upon.
-    :param integer retry_on: A list of error codes that can be retried on.
-        The method also supports a single integer to be
-        defined.
-    :param integer call_retries: The number of times to retry the call upon
-        the error code defined by the 'retry_on' parameter. Default: 3
-    :param integer retry_wait: The time in seconds to wait between retry
-        attempts. Default: 2
-
-    :returns: The object returned by the client call.
-    """
-
-    # NOTE(TheJulia): This method, as of this note, does not have direct
-    # unit tests, although is fairly well tested by the tests checking
-    # retry logic in test_baremetal_node.py.
-    log = _log.setup_logging('shade.http')
-
-    if isinstance(retry_on, int):
-        retry_on = [retry_on]
-
-    count = 0
-    while count < call_retries:
-        count += 1
-        try:
-            ret_val = client(url, **kwargs)
-        except exc.OpenStackCloudHTTPError as e:
-            if retry_on is not None and e.response.status_code in retry_on:
-                log.debug(
-                    'Received retryable error %(err)s, waiting '
-                    '%(wait)s seconds to retry',
-                    {'err': e.response.status_code, 'wait': retry_wait},
-                )
-                time.sleep(retry_wait)
-                continue
-            else:
-                raise
-        # Break out of the loop, since the loop should only continue
-        # when we encounter a known connection error.
-        return ret_val
-
-
 def parse_range(value):
     """Parse a numerical range string.
 
@@ -474,7 +365,8 @@ def range_filter(data, key, range_exp):
     :param string range_exp: The expression describing the range of values.
 
     :returns: A list subset of the original data set.
-    :raises: OpenStackCloudException on invalid range expressions.
+    :raises: :class:`~openstack.exceptions.SDKException` on invalid range
+        expressions.
     """
     filtered = []
     range_exp = str(range_exp).upper()
@@ -502,9 +394,7 @@ def range_filter(data, key, range_exp):
 
     # If parsing the range fails, it must be a bad value.
     if val_range is None:
-        raise exc.OpenStackCloudException(
-            "Invalid range value: {value}".format(value=range_exp)
-        )
+        raise exceptions.SDKException(f"Invalid range value: {range_exp}")
 
     op = val_range[0]
     if op:
@@ -543,7 +433,7 @@ def generate_patches_from_kwargs(operation, **kwargs):
     """
     patches = []
     for k, v in kwargs.items():
-        patch = {'op': operation, 'value': v, 'path': '/%s' % k}
+        patch = {'op': operation, 'value': v, 'path': f'/{k}'}
         patches.append(patch)
     return sorted(patches)
 
