@@ -10,6 +10,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import typing as ty
+
 from openstack.load_balancer.v2 import amphora as _amphora
 from openstack.load_balancer.v2 import availability_zone as _availability_zone
 from openstack.load_balancer.v2 import (
@@ -102,10 +104,10 @@ class Proxy(proxy.Proxy):
             :class:`~openstack.load_balancer.v2.load_balancer.LoadBalancer`
             instance
         :param bool ignore_missing: When set to ``False``
-            :class:`~openstack.exceptions.NotFoundException` will be raised when
-            the load balancer does not exist.
-            When set to ``True``, no exception will be set when attempting to
-            delete a nonexistent load balancer.
+            :class:`~openstack.exceptions.NotFoundException` will be raised
+            when the load balancer does not exist. When set to ``True``, no
+            exception will be set when attempting to delete a nonexistent load
+            balancer.
         :param bool cascade: If true will delete all child objects of
             the load balancer.
 
@@ -125,7 +127,7 @@ class Proxy(proxy.Proxy):
             :class:`~openstack.exceptions.NotFoundException` will be raised
             when the load balancer does not exist.
             When set to ``True``, no exception will be set when attempting
-            to delete a nonexistent load balancer.
+            to find a nonexistent load balancer.
 
         :returns: ``None``
         """
@@ -187,7 +189,7 @@ class Proxy(proxy.Proxy):
             attribute='provisioning_status',
         )
 
-    def failover_load_balancer(self, load_balancer, **attrs):
+    def failover_load_balancer(self, load_balancer):
         """Failover a load balancer
 
         :param load_balancer: The value can be the ID of a load balancer
@@ -196,7 +198,8 @@ class Proxy(proxy.Proxy):
 
         :returns: ``None``
         """
-        return self._update(_lb.LoadBalancerFailover, lb_id=load_balancer)
+        lb = self._get_resource(_lb.LoadBalancer, load_balancer)
+        lb.failover(self)
 
     def create_listener(self, **attrs):
         """Create a new listener from attributes
@@ -335,10 +338,9 @@ class Proxy(proxy.Proxy):
             :class:`~openstack.load_balancer.v2.pool.Pool`
             instance
         :param bool ignore_missing: When set to ``False``
-            :class:`~openstack.exceptions.NotFoundException` will be raised when
-            the pool does not exist.
-            When set to ``True``, no exception will be set when attempting to
-            delete a nonexistent pool.
+            :class:`~openstack.exceptions.NotFoundException` will be raised
+            when the pool does not exist. When set to ``True``, no exception
+            will be set when attempting to delete a nonexistent pool.
 
         :returns: ``None``
         """
@@ -352,7 +354,7 @@ class Proxy(proxy.Proxy):
             :class:`~openstack.exceptions.NotFoundException` will be raised
             when the pool does not exist.
             When set to ``True``, no exception will be set when attempting
-            to delete a nonexistent pool.
+            to find a nonexistent pool.
 
         :returns: ``None``
         """
@@ -565,10 +567,10 @@ class Proxy(proxy.Proxy):
             :class:`~openstack.load_balancer.v2.healthmonitor.HealthMonitor`
             instance
         :param bool ignore_missing: When set to ``False``
-            :class:`~openstack.exceptions.NotFoundException` will be raised when
-            the healthmonitor does not exist.
-            When set to ``True``, no exception will be set when attempting to
-            delete a nonexistent healthmonitor.
+            :class:`~openstack.exceptions.NotFoundException` will be raised
+            when the healthmonitor does not exist. When set to ``True``, no
+            exception will be set when attempting to delete a nonexistent
+            healthmonitor.
 
         :returns: ``None``
         """
@@ -914,10 +916,10 @@ class Proxy(proxy.Proxy):
             :class:`~openstack.load_balancer.v2.flavor_profile.FlavorProfile`
             instance
         :param bool ignore_missing: When set to ``False``
-            :class:`~openstack.exceptions.NotFoundException` will be raised when
-            the flavor profile does not exist.
-            When set to ``True``, no exception will be set when attempting to
-            delete a nonexistent flavor profile.
+            :class:`~openstack.exceptions.NotFoundException` will be raised
+            when the flavor profile does not exist. When set to ``True``, no
+            exception will be set when attempting to delete a nonexistent
+            flavor profile.
 
         :returns: ``None``
         """
@@ -935,7 +937,7 @@ class Proxy(proxy.Proxy):
             :class:`~openstack.exceptions.NotFoundException` will be raised
             when the flavor profile does not exist.
             When set to ``True``, no exception will be set when attempting
-            to delete a nonexistent flavor profile.
+            to find a nonexistent flavor profile.
 
         :returns: ``None``
         """
@@ -998,10 +1000,9 @@ class Proxy(proxy.Proxy):
         :param flavor: The flavorcan be either the ID or a
             :class:`~openstack.load_balancer.v2.flavor.Flavor` instance
         :param bool ignore_missing: When set to ``False``
-            :class:`~openstack.exceptions.NotFoundException` will be raised when
-            the flavor does not exist.
-            When set to ``True``, no exception will be set when attempting to
-            delete a nonexistent flavor.
+            :class:`~openstack.exceptions.NotFoundException` will be raised
+            when the flavor does not exist. When set to ``True``, no exception
+            will be set when attempting to delete a nonexistent flavor.
 
         :returns: ``None``
         """
@@ -1015,7 +1016,7 @@ class Proxy(proxy.Proxy):
             :class:`~openstack.exceptions.NotFoundException` will be raised
             when the flavor does not exist.
             When set to ``True``, no exception will be set when attempting
-            to delete a nonexistent flavor.
+            to find a nonexistent flavor.
 
         :returns: ``None``
         """
@@ -1070,23 +1071,25 @@ class Proxy(proxy.Proxy):
             _amphora.Amphora, amphora_id, ignore_missing=ignore_missing
         )
 
-    def configure_amphora(self, amphora_id, **attrs):
+    def configure_amphora(self, amphora_id):
         """Update the configuration of an amphora agent
 
         :param amphora_id: The ID of an amphora
 
         :returns: ``None``
         """
-        return self._update(_amphora.AmphoraConfig, amphora_id=amphora_id)
+        lb = self._get_resource(_amphora.Amphora, amphora_id)
+        lb.configure(self)
 
-    def failover_amphora(self, amphora_id, **attrs):
+    def failover_amphora(self, amphora_id):
         """Failover an amphora
 
         :param amphora_id: The ID of an amphora
 
         :returns: ``None``
         """
-        return self._update(_amphora.AmphoraFailover, amphora_id=amphora_id)
+        lb = self._get_resource(_amphora.Amphora, amphora_id)
+        lb.failover(self)
 
     def create_availability_zone_profile(self, **attrs):
         """Create a new availability zone profile from attributes
@@ -1138,10 +1141,10 @@ class Proxy(proxy.Proxy):
             :class:`~openstack.load_balancer.v2.availability_zone_profile.AvailabilityZoneProfile`
             instance
         :param bool ignore_missing: When set to ``False``
-            :class:`~openstack.exceptions.NotFoundException` will be raised when
-            the availability zone profile does not exist.
-            When set to ``True``, no exception will be set when attempting to
-            delete a nonexistent availability zone profile.
+            :class:`~openstack.exceptions.NotFoundException` will be raised
+            when the availability zone profile does not exist. When set to
+            ``True``, no exception will be set when attempting to delete a
+            nonexistent availability zone profile.
 
         :returns: ``None``
         """
@@ -1159,7 +1162,7 @@ class Proxy(proxy.Proxy):
             :class:`~openstack.exceptions.NotFoundException` will be raised
             when the availability zone profile does not exist.
             When set to ``True``, no exception will be set when attempting
-            to delete a nonexistent availability zone profile.
+            to find a nonexistent availability zone profile.
 
         :returns: ``None``
         """
@@ -1232,10 +1235,10 @@ class Proxy(proxy.Proxy):
             :class:`~openstack.load_balancer.v2.availability_zone.AvailabilityZone`
             instance
         :param bool ignore_missing: When set to ``False``
-            :class:`~openstack.exceptions.NotFoundException` will be raised when
-            the availability zone does not exist.
-            When set to ``True``, no exception will be set when attempting to
-            delete a nonexistent availability zone.
+            :class:`~openstack.exceptions.NotFoundException` will be raised
+            when the availability zone does not exist. When set to ``True``, no
+            exception will be set when attempting to delete a nonexistent
+            availability zone.
 
         :returns: ``None``
         """
@@ -1253,7 +1256,7 @@ class Proxy(proxy.Proxy):
             :class:`~openstack.exceptions.NotFoundException` will be raised
             when the availability zone does not exist.
             When set to ``True``, no exception will be set when attempting
-            to delete a nonexistent availability zone.
+            to find a nonexistent availability zone.
 
         :returns: ``None``
         """
@@ -1280,3 +1283,66 @@ class Proxy(proxy.Proxy):
         return self._update(
             _availability_zone.AvailabilityZone, availability_zone, **attrs
         )
+
+    # ========== Utilities ==========
+
+    def wait_for_status(
+        self,
+        res: resource.ResourceT,
+        status: str,
+        failures: list[str] | None = None,
+        interval: int | float | None = 2,
+        wait: int | None = None,
+        attribute: str = 'status',
+        callback: ty.Callable[[int], None] | None = None,
+    ) -> resource.ResourceT:
+        """Wait for the resource to be in a particular status.
+
+        :param session: The session to use for making this request.
+        :param resource: The resource to wait on to reach the status. The
+            resource must have a status attribute specified via ``attribute``.
+        :param status: Desired status of the resource.
+        :param failures: Statuses that would indicate the transition
+            failed such as 'ERROR'. Defaults to ['ERROR'].
+        :param interval: Number of seconds to wait between checks.
+        :param wait: Maximum number of seconds to wait for transition.
+            Set to ``None`` to wait forever.
+        :param attribute: Name of the resource attribute that contains the
+            status.
+        :param callback: A callback function. This will be called with a single
+            value, progress. This is API specific but is generally a percentage
+            value from 0-100.
+
+        :return: The updated resource.
+        :raises: :class:`~openstack.exceptions.ResourceTimeout` if the
+            transition to status failed to occur in ``wait`` seconds.
+        :raises: :class:`~openstack.exceptions.ResourceFailure` if the resource
+            transitioned to one of the states in ``failures``.
+        :raises: :class:`~AttributeError` if the resource does not have a
+            ``status`` attribute
+        """
+        return resource.wait_for_status(
+            self, res, status, failures, interval, wait, attribute, callback
+        )
+
+    def wait_for_delete(
+        self,
+        res: resource.ResourceT,
+        interval: int = 2,
+        wait: int = 120,
+        callback: ty.Callable[[int], None] | None = None,
+    ) -> resource.ResourceT:
+        """Wait for a resource to be deleted.
+
+        :param res: The resource to wait on to be deleted.
+        :param interval: Number of seconds to wait before to consecutive
+            checks.
+        :param wait: Maximum number of seconds to wait before the change.
+        :param callback: A callback function. This will be called with a single
+            value, progress, which is a percentage value from 0-100.
+
+        :returns: The resource is returned on success.
+        :raises: :class:`~openstack.exceptions.ResourceTimeout` if transition
+            to delete failed to occur in the specified seconds.
+        """
+        return resource.wait_for_delete(self, res, interval, wait, callback)
