@@ -531,7 +531,7 @@ class Proxy(proxy.Proxy):
             )
         except Exception as e:
             raise exceptions.SDKException(
-                f"Error in processing template files: {str(e)}"
+                f"Error in processing template files: {e!s}"
             )
 
     # ========== Stack events ==========
@@ -554,13 +554,15 @@ class Proxy(proxy.Proxy):
             obj = self._get(_stack.Stack, stack)
 
         if resource_name:
-            base_path = '/stacks/%(stack_name)s/%(stack_id)s/resources/%(resource_name)s/events'
             return self._list(
                 _stack_event.StackEvent,
                 stack_name=obj.name,
                 stack_id=obj.id,
                 resource_name=resource_name,
-                base_path=base_path,
+                base_path=(
+                    '/stacks/%(stack_name)s/%(stack_id)s/resources/'
+                    '%(resource_name)s/events'
+                ),
                 **attr,
             )
 
@@ -577,11 +579,11 @@ class Proxy(proxy.Proxy):
         self,
         res: resource.ResourceT,
         status: str,
-        failures: ty.Optional[list[str]] = None,
-        interval: ty.Union[int, float, None] = 2,
-        wait: ty.Optional[int] = None,
+        failures: list[str] | None = None,
+        interval: int | float | None = 2,
+        wait: int | None = None,
         attribute: str = 'status',
-        callback: ty.Optional[ty.Callable[[int], None]] = None,
+        callback: ty.Callable[[int], None] | None = None,
     ) -> resource.ResourceT:
         """Wait for the resource to be in a particular status.
 
@@ -617,7 +619,7 @@ class Proxy(proxy.Proxy):
         res: resource.ResourceT,
         interval: int = 2,
         wait: int = 120,
-        callback: ty.Optional[ty.Callable[[int], None]] = None,
+        callback: ty.Callable[[int], None] | None = None,
     ) -> resource.ResourceT:
         """Wait for a resource to be deleted.
 
