@@ -9,6 +9,9 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+
+import typing as ty
+
 from openstack import exceptions
 from openstack import proxy
 from openstack import resource
@@ -86,7 +89,7 @@ class Proxy(proxy.Proxy):
             * share_type_id: The UUID of a share type to query resources by.
             * name: The user defined name of the resource to filter resources
               by.
-            * snapshot_id: The UUID of the share’s base snapshot to filter
+            * snapshot_id: The UUID of the share's base snapshot to filter
               the request based on.
             * host: The host name of the resource to query with.
             * share_network_id: The UUID of the share network to filter
@@ -270,7 +273,7 @@ class Proxy(proxy.Proxy):
                 to filter resources.
             * project_id: The project ID of the user or service.
             * share_server_id: The UUID of the share server.
-            * snapshot_id: The UUID of the share’s base snapshot to filter
+            * snapshot_id: The UUID of the share's base snapshot to filter
                 the request based on.
             * host: The host name for the back end.
             * share_network_id: The UUID of the share network to filter
@@ -357,47 +360,6 @@ class Proxy(proxy.Proxy):
             ignore_missing=ignore_missing,
         )
 
-    def wait_for_status(
-        self,
-        res,
-        status='active',
-        failures=None,
-        interval=2,
-        wait=120,
-        status_attr_name='status',
-    ):
-        """Wait for a resource to be in a particular status.
-        :param res: The resource to wait on to reach the specified status.
-            The resource must have a ``status`` attribute.
-        :type resource: A :class:`~openstack.resource.Resource` object.
-        :param status: Desired status.
-        :param failures: Statuses that would be interpreted as failures.
-        :type failures: :py:class:`list`
-        :param interval: Number of seconds to wait before to consecutive
-            checks. Default to 2.
-        :param wait: Maximum number of seconds to wait before the change.
-            Default to 120.
-        :param status_attr_name: name of the attribute to reach the desired
-            status.
-        :returns: The resource is returned on success.
-        :raises: :class:`~openstack.exceptions.ResourceTimeout` if transition
-            to the desired status failed to occur in specified seconds.
-        :raises: :class:`~openstack.exceptions.ResourceFailure` if the resource
-            has transited to one of the failure statuses.
-        :raises: :class:`~AttributeError` if the resource does not have a
-            ``status`` attribute.
-        """
-        failures = [] if failures is None else failures
-        return resource.wait_for_status(
-            self,
-            res,
-            status,
-            failures,
-            interval,
-            wait,
-            attribute=status_attr_name,
-        )
-
     def storage_pools(self, details=True, **query):
         """Lists all back-end storage pools with details
 
@@ -619,21 +581,6 @@ class Proxy(proxy.Proxy):
             ignore_missing=ignore_missing,
         )
 
-    def wait_for_delete(self, res, interval=2, wait=120):
-        """Wait for a resource to be deleted.
-
-        :param res: The resource to wait on to be deleted.
-        :type resource: A :class:`~openstack.resource.Resource` object.
-        :param interval: Number of seconds to wait before to consecutive
-            checks. Default to 2.
-        :param wait: Maximum number of seconds to wait before the change.
-            Default to 120.
-        :returns: The resource is returned on success.
-        :raises: :class:`~openstack.exceptions.ResourceTimeout` if transition
-            to delete failed to occur in the specified seconds.
-        """
-        return resource.wait_for_delete(self, res, interval, wait)
-
     def share_snapshot_instances(self, details=True, **query):
         """Lists all share snapshot instances with details.
 
@@ -643,7 +590,7 @@ class Proxy(proxy.Proxy):
             the share snapshot instance being returned.
             Available parameters include:
 
-            * snapshot_id: The UUID of the share’s base snapshot to filter
+            * snapshot_id: The UUID of the share's base snapshot to filter
                 the request based on.
             * project_id: The project ID of the user or service making the
                 request.
@@ -1072,7 +1019,8 @@ class Proxy(proxy.Proxy):
 
         :param share_id: The ID of the share
         :param keys: The list of share metadata keys to be deleted
-        :param ignore_missing: Boolean indicating if missing keys should be ignored.
+        :param ignore_missing: Boolean indicating if missing keys should be
+            ignored.
 
         :returns: None
         :rtype: None
@@ -1113,14 +1061,14 @@ class Proxy(proxy.Proxy):
                 locks.
             * resource_type: The type of the resource that the locks pertain
                 to filter resource locks by.
-            * lock_context: The lock creator’s context to filter locks by.
+            * lock_context: The lock creator's context to filter locks by.
             * lock_reason: The lock reason that can be used to filter resource
                 locks. (Inexact search is also available with lock_reason~)
             * created_since: Search for the list of resources that were created
-                after the specified date. The date is in ‘yyyy-mm-dd’ format.
+                after the specified date. The date is in 'yyyy-mm-dd' format.
             * created_before: Search for the list of resources that were
                 created prior to the specified date. The date is in
-                ‘yyyy-mm-dd’ format.
+                'yyyy-mm-dd' format.
             * limit: The maximum number of resource locks to return.
             * offset: The offset to define start point of resource lock
                 listing.
@@ -1237,3 +1185,66 @@ class Proxy(proxy.Proxy):
         return self._update(
             _quota_class_set.QuotaClassSet, quota_class_name, **attrs
         )
+
+    # ========== Utilities ==========
+
+    def wait_for_status(
+        self,
+        res: resource.ResourceT,
+        status: str,
+        failures: list[str] | None = None,
+        interval: int | float | None = 2,
+        wait: int | None = None,
+        attribute: str = 'status',
+        callback: ty.Callable[[int], None] | None = None,
+    ) -> resource.ResourceT:
+        """Wait for the resource to be in a particular status.
+
+        :param session: The session to use for making this request.
+        :param resource: The resource to wait on to reach the status. The
+            resource must have a status attribute specified via ``attribute``.
+        :param status: Desired status of the resource.
+        :param failures: Statuses that would indicate the transition
+            failed such as 'ERROR'. Defaults to ['ERROR'].
+        :param interval: Number of seconds to wait between checks.
+        :param wait: Maximum number of seconds to wait for transition.
+            Set to ``None`` to wait forever.
+        :param attribute: Name of the resource attribute that contains the
+            status.
+        :param callback: A callback function. This will be called with a single
+            value, progress. This is API specific but is generally a percentage
+            value from 0-100.
+
+        :return: The updated resource.
+        :raises: :class:`~openstack.exceptions.ResourceTimeout` if the
+            transition to status failed to occur in ``wait`` seconds.
+        :raises: :class:`~openstack.exceptions.ResourceFailure` if the resource
+            transitioned to one of the states in ``failures``.
+        :raises: :class:`~AttributeError` if the resource does not have a
+            ``status`` attribute
+        """
+        return resource.wait_for_status(
+            self, res, status, failures, interval, wait, attribute, callback
+        )
+
+    def wait_for_delete(
+        self,
+        res: resource.ResourceT,
+        interval: int = 2,
+        wait: int = 120,
+        callback: ty.Callable[[int], None] | None = None,
+    ) -> resource.ResourceT:
+        """Wait for a resource to be deleted.
+
+        :param res: The resource to wait on to be deleted.
+        :param interval: Number of seconds to wait before to consecutive
+            checks.
+        :param wait: Maximum number of seconds to wait before the change.
+        :param callback: A callback function. This will be called with a single
+            value, progress, which is a percentage value from 0-100.
+
+        :returns: The resource is returned on success.
+        :raises: :class:`~openstack.exceptions.ResourceTimeout` if transition
+            to delete failed to occur in the specified seconds.
+        """
+        return resource.wait_for_delete(self, res, interval, wait, callback)
