@@ -24,16 +24,13 @@ import uuid
 
 from openstack.cloud import meta
 from openstack.orchestration.util import template_format
-from openstack import utils
 
 PROJECT_ID = '1c36b64c840a42cd9e9b931a369337f0'
-FLAVOR_ID = u'0c1d9008-f546-4608-9e8f-f8bdaec8dddd'
-CHOCOLATE_FLAVOR_ID = u'0c1d9008-f546-4608-9e8f-f8bdaec8ddde'
-STRAWBERRY_FLAVOR_ID = u'0c1d9008-f546-4608-9e8f-f8bdaec8dddf'
+FLAVOR_ID = '0c1d9008-f546-4608-9e8f-f8bdaec8dddd'
+CHOCOLATE_FLAVOR_ID = '0c1d9008-f546-4608-9e8f-f8bdaec8ddde'
+STRAWBERRY_FLAVOR_ID = '0c1d9008-f546-4608-9e8f-f8bdaec8dddf'
 COMPUTE_ENDPOINT = 'https://compute.example.com/v2.1'
-ORCHESTRATION_ENDPOINT = 'https://orchestration.example.com/v1/{p}'.format(
-    p=PROJECT_ID
-)
+ORCHESTRATION_ENDPOINT = f'https://orchestration.example.com/v1/{PROJECT_ID}'
 NO_MD5 = '93b885adfe0da089cdf634904fd59f71'
 NO_SHA256 = '6e340b9cffb37a989ca544e6bb780a2c78901d3fb33738768511a30617afa01d'
 FAKE_PUBLIC_KEY = (
@@ -48,30 +45,26 @@ FAKE_PUBLIC_KEY = (
 
 def make_fake_flavor(flavor_id, name, ram=100, disk=1600, vcpus=24):
     return {
-        u'OS-FLV-DISABLED:disabled': False,
-        u'OS-FLV-EXT-DATA:ephemeral': 0,
-        u'disk': disk,
-        u'id': flavor_id,
-        u'links': [
+        'OS-FLV-DISABLED:disabled': False,
+        'OS-FLV-EXT-DATA:ephemeral': 0,
+        'disk': disk,
+        'id': flavor_id,
+        'links': [
             {
-                u'href': u'{endpoint}/flavors/{id}'.format(
-                    endpoint=COMPUTE_ENDPOINT, id=flavor_id
-                ),
-                u'rel': u'self',
+                'href': f'{COMPUTE_ENDPOINT}/flavors/{flavor_id}',
+                'rel': 'self',
             },
             {
-                u'href': u'{endpoint}/flavors/{id}'.format(
-                    endpoint=COMPUTE_ENDPOINT, id=flavor_id
-                ),
-                u'rel': u'bookmark',
+                'href': f'{COMPUTE_ENDPOINT}/flavors/{flavor_id}',
+                'rel': 'bookmark',
             },
         ],
-        u'name': name,
-        u'os-flavor-access:is_public': True,
-        u'ram': ram,
-        u'rxtx_factor': 1.0,
-        u'swap': u'',
-        u'vcpus': vcpus,
+        'name': name,
+        'os-flavor-access:is_public': True,
+        'ram': ram,
+        'rxtx_factor': 1.0,
+        'swap': 0,
+        'vcpus': vcpus,
     }
 
 
@@ -232,9 +225,7 @@ def make_fake_stack_event(
                 "rel": "resource",
             },
             {
-                "href": "{endpoint}/stacks/{name}/{id}".format(
-                    endpoint=ORCHESTRATION_ENDPOINT, name=name, id=id
-                ),
+                "href": f"{ORCHESTRATION_ENDPOINT}/stacks/{name}/{id}",
                 "rel": "stack",
             },
         ],
@@ -251,48 +242,55 @@ def make_fake_image(
     md5=NO_MD5,
     sha256=NO_SHA256,
     status='active',
-    image_name=u'fake_image',
+    image_name='fake_image',
     data=None,
-    checksum=u'ee36e35a297980dee1b514de9803ec6d',
+    checksum='ee36e35a297980dee1b514de9803ec6d',
 ):
     if data:
-        md5 = utils.md5(usedforsecurity=False)
-        sha256 = hashlib.sha256()
+        md5_hash = hashlib.md5(usedforsecurity=False)
+        sha256_hash = hashlib.sha256()
+        sha512_hash = hashlib.sha512()
         with open(data, 'rb') as file_obj:
             for chunk in iter(lambda: file_obj.read(8192), b''):
-                md5.update(chunk)
-                sha256.update(chunk)
-        md5 = md5.hexdigest()
-        sha256 = sha256.hexdigest()
+                md5_hash.update(chunk)
+                sha256_hash.update(chunk)
+                sha512_hash.update(chunk)
+        md5 = md5_hash.hexdigest()
+        sha256 = sha256_hash.hexdigest()
+        sha512 = sha512_hash.hexdigest()
+    else:
+        sha512 = None
     return {
-        u'image_state': u'available',
-        u'container_format': u'bare',
-        u'min_ram': 0,
-        u'ramdisk_id': 'fake_ramdisk_id',
-        u'updated_at': u'2016-02-10T05:05:02Z',
-        u'file': '/v2/images/' + image_id + '/file',
-        u'size': 3402170368,
-        u'image_type': u'snapshot',
-        u'disk_format': u'qcow2',
-        u'id': image_id,
-        u'schema': u'/v2/schemas/image',
-        u'status': status,
-        u'tags': [],
-        u'visibility': u'private',
-        u'locations': [
-            {u'url': u'http://127.0.0.1/images/' + image_id, u'metadata': {}}
+        'image_state': 'available',
+        'container_format': 'bare',
+        'min_ram': 0,
+        'ramdisk_id': 'fake_ramdisk_id',
+        'updated_at': '2016-02-10T05:05:02Z',
+        'file': '/v2/images/' + image_id + '/file',
+        'size': 3402170368,
+        'image_type': 'snapshot',
+        'disk_format': 'qcow2',
+        'id': image_id,
+        'schema': '/v2/schemas/image',
+        'status': status,
+        'tags': [],
+        'visibility': 'private',
+        'locations': [
+            {'url': 'http://127.0.0.1/images/' + image_id, 'metadata': {}}
         ],
-        u'min_disk': 40,
-        u'virtual_size': None,
-        u'name': image_name,
-        u'checksum': md5 or checksum,
-        u'created_at': u'2016-02-10T05:03:11Z',
-        u'owner_specified.openstack.md5': md5 or NO_MD5,
-        u'owner_specified.openstack.sha256': sha256 or NO_SHA256,
-        u'owner_specified.openstack.object': 'images/{name}'.format(
-            name=image_name
-        ),
-        u'protected': False,
+        'min_disk': 40,
+        'virtual_size': None,
+        'name': image_name,
+        'checksum': md5 or checksum,
+        'created_at': '2016-02-10T05:03:11Z',
+        'owner_specified.openstack.md5': md5 or NO_MD5,
+        'owner_specified.openstack.sha256': sha256 or NO_SHA256,
+        'owner_specified.openstack.object': f'images/{image_name}',
+        'protected': False,
+        # Add secure hash fields (os_hash_algo and os_hash_value)
+        # Default to sha512 if data was provided, otherwise None
+        'os_hash_algo': 'sha512' if sha512 else None,
+        'os_hash_value': sha512 if sha512 else None,
     }
 
 
@@ -351,8 +349,6 @@ def make_fake_hypervisor(id, name):
                     "topology": {"cores": 1, "threads": 1, "sockets": 4},
                 },
                 "current_workload": 0,
-                "status": "enabled",
-                "state": "up",
                 "disk_available_least": 0,
                 "host_ip": "1.1.1.1",
                 "free_disk_gb": 1028,
