@@ -26,7 +26,7 @@ class FirewallTestCase(base.TestCase):
         return self.get_mock_url(
             'network',
             'public',
-            append=['v2.0', 'fwaas'] + list(args),
+            append=['v2.0', 'fwaas', *list(args)],
             qs_elements=params_list or None,
         )
 
@@ -183,9 +183,10 @@ class TestFirewallRule(FirewallTestCase):
             ]
         )
 
-        with mock.patch.object(
-            self.cloud.network, 'delete_firewall_rule'
-        ), mock.patch.object(self.cloud.log, 'debug'):
+        with (
+            mock.patch.object(self.cloud.network, 'delete_firewall_rule'),
+            mock.patch.object(self.cloud.log, 'debug'),
+        ):
             self.assertFalse(
                 self.cloud.delete_firewall_rule(self.firewall_rule_name)
             )
@@ -501,11 +502,14 @@ class TestFirewallPolicy(FirewallTestCase):
             ]
         )
 
-        with mock.patch.object(
-            self.cloud.network,
-            'find_firewall_policy',
-            return_value=self.mock_firewall_policy,
-        ), mock.patch.object(self.cloud.log, 'debug'):
+        with (
+            mock.patch.object(
+                self.cloud.network,
+                'find_firewall_policy',
+                return_value=self.mock_firewall_policy,
+            ),
+            mock.patch.object(self.cloud.log, 'debug'),
+        ):
             self.assertTrue(
                 self.cloud.delete_firewall_policy(
                     self.firewall_policy_name, filters
@@ -1151,9 +1155,10 @@ class TestFirewallPolicy(FirewallTestCase):
             ]
         )
 
-        with mock.patch.object(
-            self.cloud.network, 'remove_rule_from_policy'
-        ), mock.patch.object(self.cloud.log, 'debug'):
+        with (
+            mock.patch.object(self.cloud.network, 'remove_rule_from_policy'),
+            mock.patch.object(self.cloud.log, 'debug'),
+        ):
             r = self.cloud.remove_rule_from_policy(policy['id'], rule['id'])
             self.assertDictEqual(policy, r.to_dict())
             self.assert_calls()
@@ -1274,7 +1279,7 @@ class TestFirewallGroup(FirewallTestCase):
                         'network',
                         'public',
                         append=['v2.0', 'ports'],
-                        qs_elements=['name=%s' % self.mock_port['name']],
+                        qs_elements=['name={}'.format(self.mock_port['name'])],
                     ),
                     json={'ports': [self.mock_port]},
                 ),
@@ -1580,7 +1585,7 @@ class TestFirewallGroup(FirewallTestCase):
                         'network',
                         'public',
                         append=['v2.0', 'ports'],
-                        qs_elements=['name=%s' % self.mock_port['name']],
+                        qs_elements=['name={}'.format(self.mock_port['name'])],
                     ),
                     json={'ports': [self.mock_port]},
                 ),
