@@ -10,8 +10,10 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import hashlib
 import io
 import operator
+import os
 import tempfile
 from unittest import mock
 
@@ -22,7 +24,6 @@ from openstack import _log
 from openstack import exceptions
 from openstack.image.v2 import image
 from openstack.tests.unit import base
-from openstack import utils
 
 IDENTIFIER = 'IDENTIFIER'
 EXAMPLE = {
@@ -35,7 +36,10 @@ EXAMPLE = {
     'min_disk': 5,
     'name': '6',
     'owner': '7',
-    'properties': {'a': 'z', 'b': 'y', },
+    'properties': {
+        'a': 'z',
+        'b': 'y',
+    },
     'protected': False,
     'status': '8',
     'tags': ['g', 'h', 'i'],
@@ -90,7 +94,7 @@ EXAMPLE = {
 
 
 def calculate_md5_checksum(data):
-    checksum = utils.md5(usedforsecurity=False)
+    checksum = hashlib.md5(usedforsecurity=False)
     for chunk in data:
         checksum.update(chunk)
     return checksum.hexdigest()
@@ -114,9 +118,8 @@ class FakeResponse:
 
 
 class TestImage(base.TestCase):
-
     def setUp(self):
-        super(TestImage, self).setUp()
+        super().setUp()
         self.resp = mock.Mock()
         self.resp.body = None
         self.resp.json = mock.Mock(return_value=self.resp.body)
@@ -159,7 +162,7 @@ class TestImage(base.TestCase):
                 'status': 'status',
                 'tag': 'tag',
                 'updated_at': 'updated_at',
-                'visibility': 'visibility'
+                'visibility': 'visibility',
             },
             sot._query_mapping._mapping,
         )
@@ -194,8 +197,9 @@ class TestImage(base.TestCase):
         self.assertEqual(EXAMPLE['metadata'], sot.metadata)
         self.assertEqual(EXAMPLE['architecture'], sot.architecture)
         self.assertEqual(EXAMPLE['hypervisor_type'], sot.hypervisor_type)
-        self.assertEqual(EXAMPLE['instance_type_rxtx_factor'],
-                         sot.instance_type_rxtx_factor)
+        self.assertEqual(
+            EXAMPLE['instance_type_rxtx_factor'], sot.instance_type_rxtx_factor
+        )
         self.assertEqual(EXAMPLE['instance_uuid'], sot.instance_uuid)
         self.assertEqual(EXAMPLE['img_config_drive'], sot.needs_config_drive)
         self.assertEqual(EXAMPLE['kernel_id'], sot.kernel_id)
@@ -211,23 +215,27 @@ class TestImage(base.TestCase):
         self.assertEqual(EXAMPLE['hw_rng_model'], sot.hw_rng_model)
         self.assertEqual(EXAMPLE['hw_machine_type'], sot.hw_machine_type)
         self.assertEqual(EXAMPLE['hw_scsi_model'], sot.hw_scsi_model)
-        self.assertEqual(EXAMPLE['hw_serial_port_count'],
-                         sot.hw_serial_port_count)
+        self.assertEqual(
+            EXAMPLE['hw_serial_port_count'], sot.hw_serial_port_count
+        )
         self.assertEqual(EXAMPLE['hw_video_model'], sot.hw_video_model)
         self.assertEqual(EXAMPLE['hw_video_ram'], sot.hw_video_ram)
         self.assertEqual(EXAMPLE['hw_watchdog_action'], sot.hw_watchdog_action)
         self.assertEqual(EXAMPLE['os_command_line'], sot.os_command_line)
         self.assertEqual(EXAMPLE['hw_vif_model'], sot.hw_vif_model)
-        self.assertEqual(EXAMPLE['hw_vif_multiqueue_enabled'],
-                         sot.is_hw_vif_multiqueue_enabled)
+        self.assertEqual(
+            EXAMPLE['hw_vif_multiqueue_enabled'],
+            sot.is_hw_vif_multiqueue_enabled,
+        )
         self.assertEqual(EXAMPLE['hw_boot_menu'], sot.is_hw_boot_menu_enabled)
         self.assertEqual(EXAMPLE['vmware_adaptertype'], sot.vmware_adaptertype)
         self.assertEqual(EXAMPLE['vmware_ostype'], sot.vmware_ostype)
         self.assertEqual(EXAMPLE['auto_disk_config'], sot.has_auto_disk_config)
         self.assertEqual(EXAMPLE['os_type'], sot.os_type)
         self.assertEqual(EXAMPLE['os_admin_user'], sot.os_admin_user)
-        self.assertEqual(EXAMPLE['hw_qemu_guest_agent'],
-                         sot.hw_qemu_guest_agent)
+        self.assertEqual(
+            EXAMPLE['hw_qemu_guest_agent'], sot.hw_qemu_guest_agent
+        )
         self.assertEqual(EXAMPLE['os_require_quiesce'], sot.os_require_quiesce)
 
     def test_deactivate(self):
@@ -250,7 +258,7 @@ class TestImage(base.TestCase):
 
         sot.add_tag(self.sess, tag)
         self.sess.put.assert_called_with(
-            'images/IDENTIFIER/tags/%s' % tag,
+            f'images/IDENTIFIER/tags/{tag}',
         )
 
     def test_remove_tag(self):
@@ -259,17 +267,15 @@ class TestImage(base.TestCase):
 
         sot.remove_tag(self.sess, tag)
         self.sess.delete.assert_called_with(
-            'images/IDENTIFIER/tags/%s' % tag,
+            f'images/IDENTIFIER/tags/{tag}',
         )
 
     def test_import_image(self):
         sot = image.Image(**EXAMPLE)
         json = {"method": {"name": "web-download", "uri": "such-a-good-uri"}}
-        sot.import_image(self.sess, "web-download", "such-a-good-uri")
+        sot.import_image(self.sess, "web-download", uri="such-a-good-uri")
         self.sess.post.assert_called_with(
-            'images/IDENTIFIER/import',
-            headers={},
-            json=json
+            'images/IDENTIFIER/import', headers={}, json=json
         )
 
     def test_import_image_with_uri_not_web_download(self):
@@ -279,7 +285,7 @@ class TestImage(base.TestCase):
         self.sess.post.assert_called_with(
             'images/IDENTIFIER/import',
             headers={},
-            json={"method": {"name": "glance-direct"}}
+            json={"method": {"name": "glance-direct"}},
         )
 
     def test_import_image_with_store(self):
@@ -293,11 +299,16 @@ class TestImage(base.TestCase):
         }
         store = mock.MagicMock()
         store.id = "ceph_1"
-        sot.import_image(self.sess, "web-download", "such-a-good-uri", store)
+        sot.import_image(
+            self.sess,
+            "web-download",
+            uri="such-a-good-uri",
+            store=store,
+        )
         self.sess.post.assert_called_with(
             'images/IDENTIFIER/import',
             headers={'X-Image-Meta-Store': 'ceph_1'},
-            json=json
+            json=json,
         )
 
     def test_import_image_with_stores(self):
@@ -314,7 +325,7 @@ class TestImage(base.TestCase):
         sot.import_image(
             self.sess,
             "web-download",
-            "such-a-good-uri",
+            uri="such-a-good-uri",
             stores=[store],
         )
         self.sess.post.assert_called_with(
@@ -335,7 +346,7 @@ class TestImage(base.TestCase):
         sot.import_image(
             self.sess,
             "web-download",
-            "such-a-good-uri",
+            uri="such-a-good-uri",
             all_stores=True,
         )
         self.sess.post.assert_called_with(
@@ -348,21 +359,21 @@ class TestImage(base.TestCase):
         sot = image.Image(**EXAMPLE)
 
         self.assertIsNotNone(sot.upload(self.sess))
-        self.sess.put.assert_called_with('images/IDENTIFIER/file',
-                                         data=sot.data,
-                                         headers={"Content-Type":
-                                                  "application/octet-stream",
-                                                  "Accept": ""})
+        self.sess.put.assert_called_with(
+            'images/IDENTIFIER/file',
+            data=sot.data,
+            headers={"Content-Type": "application/octet-stream", "Accept": ""},
+        )
 
     def test_stage(self):
         sot = image.Image(**EXAMPLE)
 
         self.assertIsNotNone(sot.stage(self.sess))
-        self.sess.put.assert_called_with('images/IDENTIFIER/stage',
-                                         data=sot.data,
-                                         headers={"Content-Type":
-                                                  "application/octet-stream",
-                                                  "Accept": ""})
+        self.sess.put.assert_called_with(
+            'images/IDENTIFIER/stage',
+            data=sot.data,
+            headers={"Content-Type": "application/octet-stream", "Accept": ""},
+        )
 
     def test_stage_error(self):
         sot = image.Image(**EXAMPLE)
@@ -371,123 +382,315 @@ class TestImage(base.TestCase):
         self.assertRaises(exceptions.SDKException, sot.stage, self.sess)
 
     def test_download_checksum_match(self):
-        sot = image.Image(**EXAMPLE)
-
-        resp = FakeResponse(
-            b"abc",
-            headers={"Content-MD5": "900150983cd24fb0d6963f7d28e17f72",
-                     "Content-Type": "application/octet-stream"})
-        self.sess.get.return_value = resp
-
-        rv = sot.download(self.sess)
-        self.sess.get.assert_called_with('images/IDENTIFIER/file',
-                                         stream=False)
-
-        self.assertEqual(rv, resp)
-
-    def test_download_checksum_mismatch(self):
-        sot = image.Image(**EXAMPLE)
-
-        resp = FakeResponse(
-            b"abc",
-            headers={"Content-MD5": "the wrong checksum",
-                     "Content-Type": "application/octet-stream"})
-        self.sess.get.return_value = resp
-
-        self.assertRaises(exceptions.InvalidResponse, sot.download, self.sess)
-
-    def test_download_no_checksum_header(self):
-        sot = image.Image(**EXAMPLE)
-
-        resp1 = FakeResponse(
-            b"abc", headers={"Content-Type": "application/octet-stream"})
+        expected_hash = hashlib.sha512(b"abc").hexdigest()
+        example_with_hash = EXAMPLE.copy()
+        example_with_hash['os_hash_value'] = expected_hash
+        sot = image.Image(**example_with_hash)
 
+        resp1 = FakeResponse(example_with_hash)
         resp2 = FakeResponse(
-            {"checksum": "900150983cd24fb0d6963f7d28e17f72"})
+            b"abc",
+            headers={"Content-Type": "application/octet-stream"},
+        )
 
         self.sess.get.side_effect = [resp1, resp2]
 
         rv = sot.download(self.sess)
         self.sess.get.assert_has_calls(
-            [mock.call('images/IDENTIFIER/file',
-                       stream=False),
-             mock.call('images/IDENTIFIER', microversion=None, params={})])
+            [
+                mock.call(
+                    'images/IDENTIFIER',
+                    microversion=None,
+                    params={},
+                    skip_cache=False,
+                ),
+                mock.call('images/IDENTIFIER/file', stream=False),
+            ]
+        )
 
-        self.assertEqual(rv, resp1)
+        self.assertEqual(rv, resp2)
+
+    def test_download_checksum_mismatch(self):
+        example_with_wrong_hash = EXAMPLE.copy()
+        example_with_wrong_hash['os_hash_value'] = "wrong_hash_value"
+        sot = image.Image(**example_with_wrong_hash)
+
+        resp1 = FakeResponse(example_with_wrong_hash)
+        resp2 = FakeResponse(
+            b"abc",
+            headers={"Content-Type": "application/octet-stream"},
+        )
+
+        self.sess.get.side_effect = [resp1, resp2]
+
+        self.assertRaises(exceptions.InvalidResponse, sot.download, self.sess)
+
+    def test_download_md5_fallback(self):
+        expected_md5 = hashlib.md5(b"abc", usedforsecurity=False).hexdigest()
+        example_md5_only = EXAMPLE.copy()
+        example_md5_only['os_hash_algo'] = None
+        example_md5_only['os_hash_value'] = None
+        example_md5_only['checksum'] = expected_md5
+        sot = image.Image(**example_md5_only)
+
+        resp1 = FakeResponse(example_md5_only)
+        resp2 = FakeResponse(
+            b"abc", headers={"Content-Type": "application/octet-stream"}
+        )
+
+        self.sess.get.side_effect = [resp1, resp2]
+
+        rv = sot.download(self.sess)
+        self.sess.get.assert_has_calls(
+            [
+                mock.call(
+                    'images/IDENTIFIER',
+                    microversion=None,
+                    params={},
+                    skip_cache=False,
+                ),
+                mock.call('images/IDENTIFIER/file', stream=False),
+            ]
+        )
+
+        self.assertEqual(rv, resp2)
 
     def test_download_no_checksum_at_all2(self):
-        sot = image.Image(**EXAMPLE)
+        # No hash available at all
+        example_no_hash = EXAMPLE.copy()
+        example_no_hash['os_hash_algo'] = None
+        example_no_hash['os_hash_value'] = None
+        example_no_hash['checksum'] = None
+        sot = image.Image(**example_no_hash)
 
-        resp1 = FakeResponse(
-            b"abc", headers={"Content-Type": "application/octet-stream"})
-
-        resp2 = FakeResponse({"checksum": None})
+        resp1 = FakeResponse(example_no_hash)
+        resp2 = FakeResponse(
+            b"abc", headers={"Content-Type": "application/octet-stream"}
+        )
 
         self.sess.get.side_effect = [resp1, resp2]
 
         with self.assertLogs(logger='openstack', level="WARNING") as log:
             rv = sot.download(self.sess)
 
-            self.assertEqual(len(log.records), 1,
-                             "Too many warnings were logged")
             self.assertEqual(
-                "Unable to verify the integrity of image %s",
-                log.records[0].msg)
+                len(log.records), 1, "Too many warnings were logged"
+            )
             self.assertEqual(
-                (sot.id,),
-                log.records[0].args)
+                "Unable to verify the integrity of image %s "
+                "- no hash available",
+                log.records[0].msg,
+            )
+            self.assertEqual((sot.id,), log.records[0].args)
 
         self.sess.get.assert_has_calls(
-            [mock.call('images/IDENTIFIER/file',
-                       stream=False),
-             mock.call('images/IDENTIFIER', microversion=None, params={})])
+            [
+                mock.call(
+                    'images/IDENTIFIER',
+                    microversion=None,
+                    params={},
+                    skip_cache=False,
+                ),
+                mock.call('images/IDENTIFIER/file', stream=False),
+            ]
+        )
 
-        self.assertEqual(rv, resp1)
+        self.assertEqual(rv, resp2)
 
     def test_download_stream(self):
-        sot = image.Image(**EXAMPLE)
+        expected_hash = hashlib.sha512(b"abc").hexdigest()
+        example_with_hash = EXAMPLE.copy()
+        example_with_hash['os_hash_value'] = expected_hash
+        sot = image.Image(**example_with_hash)
 
-        resp = FakeResponse(
+        resp1 = FakeResponse(example_with_hash)
+        resp2 = FakeResponse(
             b"abc",
-            headers={"Content-MD5": "900150983cd24fb0d6963f7d28e17f72",
-                     "Content-Type": "application/octet-stream"})
-        self.sess.get.return_value = resp
+            headers={"Content-Type": "application/octet-stream"},
+        )
+
+        self.sess.get.side_effect = [resp1, resp2]
 
         rv = sot.download(self.sess, stream=True)
-        self.sess.get.assert_called_with('images/IDENTIFIER/file', stream=True)
+        self.sess.get.assert_has_calls(
+            [
+                mock.call(
+                    'images/IDENTIFIER',
+                    microversion=None,
+                    params={},
+                    skip_cache=False,
+                ),
+                mock.call('images/IDENTIFIER/file', stream=True),
+            ]
+        )
 
-        self.assertEqual(rv, resp)
+        self.assertEqual(rv, resp2)
+        self.assertIsNone(rv.headers.get('content-md5'))
 
     def test_image_download_output_fd(self):
         output_file = io.BytesIO()
-        sot = image.Image(**EXAMPLE)
+        expected_hash = hashlib.sha512(b'0102').hexdigest()
+        example_with_hash = EXAMPLE.copy()
+        example_with_hash['os_hash_value'] = expected_hash
+        sot = image.Image(**example_with_hash)
+
+        fetch_response = FakeResponse(example_with_hash)
         response = mock.Mock()
         response.status_code = 200
         response.iter_content.return_value = [b'01', b'02']
-        response.headers = {
-            'Content-MD5':
-            calculate_md5_checksum(response.iter_content.return_value)
-        }
-        self.sess.get = mock.Mock(return_value=response)
+        response.headers = {}
+
+        self.sess.get = mock.Mock(side_effect=[fetch_response, response])
         sot.download(self.sess, output=output_file)
         output_file.seek(0)
         self.assertEqual(b'0102', output_file.read())
 
     def test_image_download_output_file(self):
-        sot = image.Image(**EXAMPLE)
+        expected_hash = hashlib.sha512(b'0102').hexdigest()
+        example_with_hash = EXAMPLE.copy()
+        example_with_hash['os_hash_value'] = expected_hash
+        sot = image.Image(**example_with_hash)
+
+        fetch_response = FakeResponse(example_with_hash)
         response = mock.Mock()
         response.status_code = 200
         response.iter_content.return_value = [b'01', b'02']
-        response.headers = {
-            'Content-MD5':
-            calculate_md5_checksum(response.iter_content.return_value)
-        }
-        self.sess.get = mock.Mock(return_value=response)
+        response.headers = {}
 
-        output_file = tempfile.NamedTemporaryFile()
-        sot.download(self.sess, output=output_file.name)
-        output_file.seek(0)
-        self.assertEqual(b'0102', output_file.read())
+        self.sess.get = mock.Mock(side_effect=[fetch_response, response])
+
+        output_file = tempfile.NamedTemporaryFile(delete=False)
+        output_file.close()
+        try:
+            sot.download(self.sess, output=output_file.name)
+            with open(output_file.name, 'rb') as fd:
+                self.assertEqual(b'0102', fd.read())
+        finally:
+            os.unlink(output_file.name)
+
+    def test_download_secure_hash_sha256(self):
+        expected_hash = hashlib.sha256(b"abc").hexdigest()
+        example_with_sha256 = EXAMPLE.copy()
+        example_with_sha256['os_hash_algo'] = 'sha256'
+        example_with_sha256['os_hash_value'] = expected_hash
+        sot = image.Image(**example_with_sha256)
+
+        resp1 = FakeResponse(example_with_sha256)
+        resp2 = FakeResponse(
+            b"abc",
+            headers={"Content-Type": "application/octet-stream"},
+        )
+
+        self.sess.get.side_effect = [resp1, resp2]
+
+        rv = sot.download(self.sess)
+        self.assertEqual(rv, resp2)
+
+    def test_download_secure_hash_sha384(self):
+        expected_hash = hashlib.sha384(b"abc").hexdigest()
+        example_with_sha384 = EXAMPLE.copy()
+        example_with_sha384['os_hash_algo'] = 'sha384'
+        example_with_sha384['os_hash_value'] = expected_hash
+        sot = image.Image(**example_with_sha384)
+
+        resp1 = FakeResponse(example_with_sha384)
+        resp2 = FakeResponse(
+            b"abc",
+            headers={"Content-Type": "application/octet-stream"},
+        )
+
+        self.sess.get.side_effect = [resp1, resp2]
+
+        rv = sot.download(self.sess)
+        self.assertEqual(rv, resp2)
+
+    def test_download_content_md5_header_ignored(self):
+        correct_hash = hashlib.sha512(b"abc").hexdigest()
+        example_with_hash = EXAMPLE.copy()
+        example_with_hash['os_hash_value'] = correct_hash
+        sot = image.Image(**example_with_hash)
+
+        resp1 = FakeResponse(example_with_hash)
+        resp2 = FakeResponse(
+            b"abc",
+            headers={
+                "Content-MD5": "wrong_header_hash_that_should_be_ignored",
+                "Content-Type": "application/octet-stream",
+            },
+        )
+
+        self.sess.get.side_effect = [resp1, resp2]
+
+        # Succeeds since only metadata hash is used
+        rv = sot.download(self.sess)
+        self.assertEqual(rv, resp2)
+
+    def test_download_secure_hash_mismatch_sha512(self):
+        example_with_wrong_hash = EXAMPLE.copy()
+        example_with_wrong_hash['os_hash_value'] = "wrong_sha512_hash"
+        sot = image.Image(**example_with_wrong_hash)
+
+        resp1 = FakeResponse(example_with_wrong_hash)
+        resp2 = FakeResponse(
+            b"abc",
+            headers={"Content-Type": "application/octet-stream"},
+        )
+
+        self.sess.get.side_effect = [resp1, resp2]
+
+        self.assertRaises(exceptions.InvalidResponse, sot.download, self.sess)
+
+    def test_download_md5_fallback_mismatch(self):
+        example_md5_only = EXAMPLE.copy()
+        example_md5_only['os_hash_algo'] = None
+        example_md5_only['os_hash_value'] = None
+        example_md5_only['checksum'] = "wrong_md5_checksum"
+        sot = image.Image(**example_md5_only)
+
+        resp1 = FakeResponse(example_md5_only)
+        resp2 = FakeResponse(
+            b"abc",
+            headers={"Content-Type": "application/octet-stream"},
+        )
+
+        self.sess.get.side_effect = [resp1, resp2]
+
+        self.assertRaises(exceptions.InvalidResponse, sot.download, self.sess)
+
+    def test_download_unsupported_hash_algo_raises(self):
+        example_unsupported = EXAMPLE.copy()
+        example_unsupported['os_hash_algo'] = 'unsupported_algo'
+        example_unsupported['os_hash_value'] = 'some_hash_value'
+        sot = image.Image(**example_unsupported)
+
+        resp1 = FakeResponse(example_unsupported)
+        resp2 = FakeResponse(
+            b"abc",
+            headers={"Content-Type": "application/octet-stream"},
+        )
+
+        self.sess.get.side_effect = [resp1, resp2]
+
+        self.assertRaises(exceptions.SDKException, sot.download, self.sess)
+
+    def test_download_unsupported_hash_algo_falls_back_to_md5(self):
+        correct_md5 = hashlib.md5(b"abc", usedforsecurity=False).hexdigest()
+        example_unsupported = EXAMPLE.copy()
+        example_unsupported['os_hash_algo'] = 'ancient_hash_algo'
+        example_unsupported['os_hash_value'] = 'irrelevant_hash'
+        example_unsupported['checksum'] = correct_md5
+        sot = image.Image(**example_unsupported)
+
+        resp1 = FakeResponse(example_unsupported)
+        resp2 = FakeResponse(
+            b"abc",
+            headers={"Content-Type": "application/octet-stream"},
+        )
+
+        self.sess.get.side_effect = [resp1, resp2]
+
+        rv = sot.download(self.sess)
+        self.assertEqual(rv, resp2)
 
     def test_image_update(self):
         values = EXAMPLE.copy()
@@ -506,9 +709,10 @@ class TestImage(base.TestCase):
         resp.status_code = 200
         self.sess.patch.return_value = resp
 
-        value = [{"value": "fake_name", "op": "replace", "path": "/name"},
-                 {"value": "fake_value", "op": "add",
-                  "path": "/instance_uuid"}]
+        value = [
+            {"value": "fake_name", "op": "replace", "path": "/name"},
+            {"value": "fake_value", "op": "add", "path": "/instance_uuid"},
+        ]
 
         sot.name = 'fake_name'
         sot.instance_uuid = 'fake_value'
@@ -520,7 +724,8 @@ class TestImage(base.TestCase):
         self.assertEqual(url, call_args[0])
         self.assertEqual(
             sorted(value, key=operator.itemgetter('value')),
-            sorted(call_kwargs['json'], key=operator.itemgetter('value')))
+            sorted(call_kwargs['json'], key=operator.itemgetter('value')),
+        )
 
     def test_image_find(self):
         sot = image.Image()
@@ -532,20 +737,33 @@ class TestImage(base.TestCase):
             # Then list with no results
             FakeResponse({'images': []}),
             # And finally new list of hidden images with one searched
-            FakeResponse({'images': [EXAMPLE]})
-
+            FakeResponse({'images': [EXAMPLE]}),
         ]
 
         result = sot.find(self.sess, EXAMPLE['name'])
 
-        self.sess.get.assert_has_calls([
-            mock.call('images/' + EXAMPLE['name'], microversion=None,
-                      params={}),
-            mock.call('/images', headers={'Accept': 'application/json'},
-                      microversion=None, params={'name': EXAMPLE['name']}),
-            mock.call('/images', headers={'Accept': 'application/json'},
-                      microversion=None, params={'os_hidden': True})
-        ])
+        self.sess.get.assert_has_calls(
+            [
+                mock.call(
+                    'images/' + EXAMPLE['name'],
+                    microversion=None,
+                    params={},
+                    skip_cache=False,
+                ),
+                mock.call(
+                    '/images',
+                    headers={'Accept': 'application/json'},
+                    microversion=None,
+                    params={'name': EXAMPLE['name']},
+                ),
+                mock.call(
+                    '/images',
+                    headers={'Accept': 'application/json'},
+                    microversion=None,
+                    params={'os_hidden': True},
+                ),
+            ]
+        )
 
         self.assertIsInstance(result, image.Image)
         self.assertEqual(IDENTIFIER, result.id)
