@@ -21,15 +21,17 @@ from openstack.orchestration.v1 import software_config as sc
 from openstack.orchestration.v1 import software_deployment as sd
 from openstack.orchestration.v1 import stack
 from openstack.orchestration.v1 import stack_environment
+from openstack.orchestration.v1 import stack_event
 from openstack.orchestration.v1 import stack_files
 from openstack.orchestration.v1 import stack_template
 from openstack.orchestration.v1 import template
+from openstack import proxy
 from openstack.tests.unit import test_proxy_base
 
 
 class TestOrchestrationProxy(test_proxy_base.TestProxyBase):
     def setUp(self):
-        super(TestOrchestrationProxy, self).setUp()
+        super().setUp()
         self.proxy = _proxy.Proxy(self.session)
 
 
@@ -94,7 +96,7 @@ class TestOrchestrationStack(TestOrchestrationProxy):
 
     def test_update_stack(self):
         self._verify(
-            'openstack.orchestration.v1.stack.Stack.update',
+            'openstack.orchestration.v1.stack.Stack.commit',
             self.proxy.update_stack,
             expected_result='result',
             method_args=['stack'],
@@ -104,7 +106,7 @@ class TestOrchestrationStack(TestOrchestrationProxy):
 
     def test_update_stack_preview(self):
         self._verify(
-            'openstack.orchestration.v1.stack.Stack.update',
+            'openstack.orchestration.v1.stack.Stack.commit',
             self.proxy.update_stack,
             expected_result='result',
             method_args=['stack'],
@@ -121,6 +123,51 @@ class TestOrchestrationStack(TestOrchestrationProxy):
             expected_args=[self.proxy],
         )
 
+    @mock.patch.object(stack.Stack, 'find')
+    def test_export_stack_with_identity(self, mock_find):
+        stack_id = '1234'
+        stack_name = 'test_stack'
+        stk = stack.Stack(id=stack_id, name=stack_name)
+        mock_find.return_value = stk
+
+        self._verify(
+            'openstack.orchestration.v1.stack.Stack.export',
+            self.proxy.export_stack,
+            method_args=['IDENTITY'],
+            expected_args=[self.proxy],
+        )
+        mock_find.assert_called_once_with(
+            mock.ANY, 'IDENTITY', ignore_missing=False
+        )
+
+    def test_export_stack_with_object(self):
+        stack_id = '1234'
+        stack_name = 'test_stack'
+        stk = stack.Stack(id=stack_id, name=stack_name)
+
+        self._verify(
+            'openstack.orchestration.v1.stack.Stack.export',
+            self.proxy.export_stack,
+            method_args=[stk],
+            expected_args=[self.proxy],
+        )
+
+    def test_suspend_stack(self):
+        self._verify(
+            'openstack.orchestration.v1.stack.Stack.suspend',
+            self.proxy.suspend_stack,
+            method_args=['stack'],
+            expected_args=[self.proxy],
+        )
+
+    def test_resume_stack(self):
+        self._verify(
+            'openstack.orchestration.v1.stack.Stack.resume',
+            self.proxy.resume_stack,
+            method_args=['stack'],
+            expected_args=[self.proxy],
+        )
+
     def test_delete_stack(self):
         self.verify_delete(self.proxy.delete_stack, stack.Stack, False)
 
@@ -301,12 +348,12 @@ class TestOrchestrationResource(TestOrchestrationProxy):
     @mock.patch.object(resource.Resource, 'list')
     def test_resources_stack_not_found(self, mock_list, mock_find):
         stack_name = 'test_stack'
-        mock_find.side_effect = exceptions.ResourceNotFound(
+        mock_find.side_effect = exceptions.NotFoundException(
             'No stack found for test_stack'
         )
 
         ex = self.assertRaises(
-            exceptions.ResourceNotFound, self.proxy.resources, stack_name
+            exceptions.NotFoundException, self.proxy.resources, stack_name
         )
         self.assertEqual('No stack found for test_stack', str(ex))
 
@@ -397,7 +444,7 @@ class TestOrchestrationTemplate(TestOrchestrationProxy):
             template_url=None,
         )
         self.assertEqual(
-            "'template_url' must be specified when template is " "None",
+            "'template_url' must be specified when template is None",
             str(err),
         )
 
@@ -453,3 +500,59 @@ class TestExtractName(TestOrchestrationProxy):
     def test_extract_name(self):
         results = self.proxy._extract_name(self.url)
         self.assertEqual(self.parts, results)
+
+
+class TestOrchestrationStackEvents(TestOrchestrationProxy):
+    def test_stack_events_with_stack_object(self):
+        stack_id = '1234'
+        stack_name = 'test_stack'
+        stk = stack.Stack(id=stack_id, name=stack_name)
+
+        self._verify(
+            'openstack.proxy.Proxy._list',
+            self.proxy.stack_events,
+            method_args=[stk],
+            expected_args=[stack_event.StackEvent],
+            expected_kwargs={
+                'stack_name': stack_name,
+                'stack_id': stack_id,
+            },
+        )
+
+    @mock.patch.object(proxy.Proxy, '_get')
+    def test_stack_events_with_stack_id(self, mock_get):
+        stack_id = '1234'
+        stack_name = 'test_stack'
+        stk = stack.Stack(id=stack_id, name=stack_name)
+        mock_get.return_value = stk
+
+        self._verify(
+            'openstack.proxy.Proxy._list',
+            self.proxy.stack_events,
+            method_args=[stk],
+            expected_args=[stack_event.StackEvent],
+            expected_kwargs={
+                'stack_name': stack_name,
+                'stack_id': stack_id,
+            },
+        )
+
+    def test_stack_events_with_resource_name(self):
+        stack_id = '1234'
+        stack_name = 'test_stack'
+        resource_name = 'id'
+        base_path = '/stacks/%(stack_name)s/%(stack_id)s/resources/%(resource_name)s/events'  # noqa: E501
+        stk = stack.Stack(id=stack_id, name=stack_name)
+
+        self._verify(
+            'openstack.proxy.Proxy._list',
+            self.proxy.stack_events,
+            method_args=[stk, resource_name],
+            expected_args=[stack_event.StackEvent],
+            expected_kwargs={
+                'stack_name': stack_name,
+                'stack_id': stack_id,
+                'resource_name': resource_name,
+                'base_path': base_path,
+            },
+        )
